#
# spec file for package net-snmp
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# compatibility for SLES11 <=SP1
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

%define pkg_name net-snmp
%ifnarch s390 s390x
%define netsnmp_with_sensors 1
%endif
%define netsnmp_check 1
%define netsnmp_logfile /var/log/net-snmpd.log
%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
%define netsnmp_agentx_socket_dir_fhs %{_rundir}/agentx
%define netsnmp_agentx_socket_dir_rfc /var/agentx

Name:           net-snmp
Version:        5.7.3
Release:        4.5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  openssl-devel
BuildRequires:  procps
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  rpm-devel
BuildRequires:  tcpd-devel
%if 0%{?netsnmp_with_sensors}
BuildRequires:  libsensors4-devel
%endif
Requires:       logrotate
Requires:       perl-SNMP = %{version}
Requires:       perl-TermReadKey
PreReq:         %insserv_prereq %fillup_prereq /sbin/chkconfig
Url:            http://sourceforge.net/projects/net-snmp
Source:         http://sourceforge.net/projects/net-snmp/files/net-snmp/%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        rc.snmpd
Source2:        snmpd.conf
Source3:        README.SUSE
Source4:        rc.snmptrapd
Source5:        net-snmp.logrotate
Source6:        test_installed
Source7:        net-snmp.sysconfig
Source8:        net-snmp-rpmlintrc
Source9:        baselibs.conf
Patch1:         net-snmp-5.7.3-socket-path.patch
Patch2:         net-snmp-5.7.3-testing-empty-arptable.patch
Patch3:         net-snmp-5.7.3-pie.patch
Patch4:         net-snmp-5.7.3-net-snmp-config-headercheck.patch
Patch5:         net-snmp-5.7.3-perl-tk-warning.patch
Patch6:         net-snmp-5.7.3-velocity-mib.patch
Patch7:         net-snmp-5.7.3-fix-snmpd-crashing-when-an-agentx-disconnects.patch
Patch8:         net-snmp-5.7.3-netgroups.patch
Patch9:         net-snmp-5.7.3-snmpstatus-suppress-output.patch
Patch10:        net-snmp-5.7.3-fix-snmp_pdu_parse-incomplete.patch
Patch11:        net-snmp-reenable-md5-fips.patch
#
Summary:        SNMP Daemon
License:        BSD-3-Clause and MIT
Group:          Productivity/Networking/Other

%description
Net-SNMP is a suite of applications used to implement SNMP v1, SNMP v2c
and SNMP v3 using both IPv4 and IPv6. The suite includes:

- An extensible agent for responding to SNMP queries including built-in
  support for a wide range of MIB information modules
- Command-line applications to retrieve and manipulate information from
  SNMP-capable devices
- A daemon application for receiving SNMP notifications
- A library for developing new SNMP applications, with C and Perl APIs
- A graphical MIB browser.

This package was originally based on the CMU 2.1.2.1 snmp code. It was
renamed from cmu-snmp to ucd-snmp in 1995 and later renamed from ucd-snmp
to net-snmp in November 2000.


%define library_name libsnmp30

%package     -n libsnmp30
Requires:       perl-base = %{perl_version}
Requires:       snmp-mibs = %{version}
#
Summary:        Shared Libraries from net-snmp
License:        BSD-3-Clause and MIT
Group:          Productivity/Networking/Other

%description -n libsnmp30
Net-SNMP is a suite of applications used to implement SNMP v1, SNMP v2c
and SNMP v3 using both IPv4 and IPv6. The suite includes:

* An extensible agent for responding to SNMP queries including built-in
  support for a wide range of MIB information modules
* Command-line applications to retrieve and manipulate information from
  SNMP-capable devices
* A daemon application for receiving SNMP notifications
* A library for developing new SNMP applications, with C and Perl APIs
* A graphical MIB browser.

This package holds the shared libraries from the net-snmp package.

%package devel
Requires:       %{library_name} = %{version}
# for mib2c
Requires:       libopenssl-devel
Requires:       perl
Requires:       perl-SNMP = %{version}
Requires:       rpm-devel
Requires:       tcpd-devel
Requires:       zlib-devel
%if 0%{?netsnmp_with_sensors}
Requires:       libsensors4-devel
%endif
#
Summary:        Development files from net-snmp
License:        BSD-3-Clause and MIT
Group:          Development/Libraries/C and C++

%description devel
Net-SNMP is a suite of applications used to implement SNMP v1, SNMP v2c
and SNMP v3 using both IPv4 and IPv6. The suite includes:

* An extensible agent for responding to SNMP queries including built-in
  support for a wide range of MIB information modules
* Command-line applications to retrieve and manipulate information from
  SNMP-capable devices
* A daemon application for receiving SNMP notifications
* A library for developing new SNMP applications, with C and Perl APIs
* A graphical MIB browser.

This package holds the development headers, libraries and API documentation
from the net-snmp package.


%package     -n snmp-mibs
#
Summary:        MIB files from net-snmp
License:        BSD-3-Clause and MIT
Group:          Productivity/Networking/Other

%description -n snmp-mibs
Net-SNMP is a suite of applications used to implement SNMP v1, SNMP v2c
and SNMP v3 using both IPv4 and IPv6. The suite includes:

- An extensible agent for responding to SNMP queries including built-in
  support for a wide range of MIB information modules
- Command-line applications to retrieve and manipulate information from
  SNMP-capable devices
- A daemon application for receiving SNMP notifications
- A library for developing new SNMP applications, with C and Perl APIs
- A graphical MIB browser.

This package holds the MIB files from the net-snmp package.


%package     -n perl-SNMP
Requires:       %{pkg_name} = %{version}
Requires:       perl-base = %{perl_version}
#
Summary:        Perl5 SNMP Extension Module
License:        GPL-2.0+
Group:          Development/Libraries/Perl

%description -n perl-SNMP
The Perl5 'SNMP' Extension Module v3.1.0 for the UCD SNMPv3 library.


%package python
Summary:        The Python 'netsnmp' module for the Net-SNMP
License:        BSD-3-Clause and MIT
Group:          Development/Libraries/Python

%description python
The 'netsnmp' module provides a full featured, tri-lingual SNMP (SNMPv3,
SNMPv2c, SNMPv1) client API. The 'netsnmp' module internals rely on the
Net-SNMP toolkit library.


%prep
%setup -q -n %{pkg_name}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1

%build
MIBS="misc/ipfwacc ucd-snmp/diskio etherlike-mib rmon-mib velocity smux \
      ip-mib/ipv4InterfaceTable ip-mib/ipv6InterfaceTable \
      ip-mib/ipDefaultRouterTable ip-mib/ipAddressPrefixTable \
      ip-mib/ipv6ScopeZoneIndexTable ip-mib/ipIfStatsTable"

%if 0%{?netsnmp_with_sensors}
MIBS="$MIBS ucd-snmp/lmsensorsMib"
%endif

autoreconf
%configure \
	--with-sys-contact="root@localhost" \
	--with-sys-location="unknown" \
	--with-mib-modules="$MIBS" \
	--with-cflags="%{optflags} -fstack-protector-all" \
	--with-persistent-directory="/var/lib/net-snmp" \
	--with-agentx-socket="%{netsnmp_agentx_socket_dir_fhs}/master" \
	--with-logfile="%{netsnmp_logfile}" \
	--with-libwrap="%{_prefix}" \
	--with-perl-modules="INSTALLDIRS=vendor" \
	--with-defaults \
	--enable-shared \
	--disable-static \
	--enable-as-needed \
	--without-root-access \
	--enable-local-smux \
	--enable-ipv6 \
        --enable-ucd-snmp-compatibility \
        --with-security-modules=tsm \
        --with-transports=TLSTCP,DTLSUDP
# Parallel building is disabled because dependencies between the Perl
# module and libnetsnmp are not correctly defined.
make #%{?_smp_mflags}

pushd python
%{__python} setup.py --basedir="../" build
popd

%check
%if 0%{?netsnmp_check}
%ifnarch %arm
ulimit -c unlimited
%{__make} test ||:
%{__make} test TESTOPTS='-P tcp' ||:
%endif
%{__make} perlmodules ||:
LD_RUN_PATH="$PWD/snmplib/.libs" LD_LIBRARY_PATH="${PWD}/snmplib/.libs:${PWD}/agent/.libs:${PWD}/agent/helpers/.libs" %{__make} perltest ||:
%endif

%install
%makeinstall INSTALL_PREFIX=%{buildroot}
%{__install} -Dd %{buildroot}/var/log %{buildroot}/var/lib/net-snmp %{buildroot}/usr/lib/net-snmp/agents %{buildroot}%{netsnmp_agentx_socket_dir_fhs}
%{__install} -D -m 0755 %{SOURCE1} %{buildroot}/etc/init.d/snmpd
%{__install} -D -m 0755 %{SOURCE4} %{buildroot}/etc/init.d/snmptrapd
%{__install} -D -m 0600 %{SOURCE2} %{buildroot}/etc/snmp/snmpd.conf
%{__install} -m 0644 %{SOURCE3} .
%{__install} -m 0644 %{SOURCE4} .
%{__install} -D -m 0644 %{SOURCE5} %{buildroot}/etc/logrotate.d/net-snmp
%{__install} -m 0744 %{SOURCE6} testing/
%{__ln_s} -f /etc/init.d/snmpd %{buildroot}%{_sbindir}/rcsnmpd
%{__ln_s} -f /etc/init.d/snmptrapd %{buildroot}%{_sbindir}/rcsnmptrapd
%{__install} -m 0644 /dev/null  %{buildroot}%{netsnmp_logfile}
pushd perl
    %perl_make_install
    %perl_process_packlist
    %{__rm} -f %{buildroot}/%{perl_vendorarch}/Bundle/Makefile.subs.pl
popd
pushd python
%{__python} setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd
%{__grep} -v "^#define PACKAGE" %{buildroot}%{_includedir}/net-snmp/net-snmp-config.h > \
    %{buildroot}%{_includedir}/net-snmp/net-snmp-config.h.new
%{__mv}  %{buildroot}%{_includedir}/net-snmp/net-snmp-config.h{.new,}
%{__install} -D -m 0644 %{S:7} \
    %{buildroot}/var/adm/fillup-templates/sysconfig.%{pkg_name}
#
%{__ln_s} -f %{netsnmp_agentx_socket_dir_fhs} %{buildroot}%{netsnmp_agentx_socket_dir_rfc}
#
rm -f "%buildroot/%_libdir"/*.la

%preun
%stop_on_removal snmpd
%stop_on_removal snmptrapd

%post
/sbin/chkconfig -c snmpd 2> /dev/null && FIRST_ARG=2
%{fillup_only}

%postun
%restart_on_update snmpd
%restart_on_update snmptrapd
%{insserv_cleanup}

%post   -n %{library_name} -p /sbin/ldconfig

%postun -n %{library_name} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AGENT.txt COPYING EXAMPLE.conf EXAMPLE.conf.def
%doc FAQ NEWS TODO CHANGES
%doc README README.agent-mibs README.agentx README.krb5 README.snmpv3 README.thread
%dir /etc/snmp
%config(noreplace) /etc/snmp/snmpd.conf
%config /etc/init.d/snmpd
%config /etc/init.d/snmptrapd
%{_bindir}/encode_keychange
%{_bindir}/fixproc
%{_bindir}/ipf-mod.pl
%{_bindir}/net-snmp-config
%{_bindir}/snmpbulkget
%{_bindir}/snmpbulkwalk
%{_bindir}/snmpcheck
%{_bindir}/snmpconf
%{_bindir}/snmpdelta
%{_bindir}/snmpdf
%{_bindir}/snmpget
%{_bindir}/snmpgetnext
%{_bindir}/snmpinform
%{_bindir}/snmpnetstat
%{_bindir}/snmpset
%{_bindir}/snmpstatus
%{_bindir}/snmptable
%{_bindir}/snmptest
%{_bindir}/snmptls
%{_bindir}/snmptranslate
%{_bindir}/snmptrap
%{_bindir}/snmpusm
%{_bindir}/snmpvacm
%{_bindir}/snmpwalk
%{_bindir}/traptoemail
%{_bindir}/net-snmp-create-v3-user
%{_bindir}/net-snmp-cert
%{_bindir}/agentxtrap
%{_bindir}/snmp-bridge-mib
%dir %{_prefix}/lib/net-snmp
%dir %{_prefix}/lib/net-snmp/agents
%{_mandir}/man[158]/*
%{_sbindir}/*
/var/lib/net-snmp
%dir %ghost %attr(700,root,root) %{netsnmp_agentx_socket_dir_fhs}
%ghost %{netsnmp_logfile}
%config(noreplace) /etc/logrotate.d/net-snmp
/var/adm/fillup-templates/sysconfig.%{pkg_name}
%{netsnmp_agentx_socket_dir_rfc}
%{_datadir}/snmp/snmpconf-data/
%{_datadir}/snmp/snmp_perl.pl
%{_datadir}/snmp/snmp_perl_trapd.pl

%files -n snmp-mibs
%defattr(-,root,root)
%dir %{_datadir}/snmp
%{_datadir}/snmp/mibs/

%files -n %{library_name}
%defattr(-,root,root)
%{_libdir}/libsnmp*.so.*
%{_libdir}/libnetsnmp*.so.*

%files devel
%defattr(-,root,root)
%doc ChangeLog PORTING
%{_mandir}/man3/*
%{_includedir}/ucd-snmp
%{_includedir}/net-snmp
%{_libdir}/libsnmp*.so
%{_libdir}/libnetsnmp*.so
%{_bindir}/mib2c
%{_bindir}/mib2c-update
%{_datadir}/snmp/mib2c*

%files -n perl-SNMP
%defattr(-,root,root)
%{perl_vendorarch}/auto/SNMP
%{perl_vendorarch}/auto/NetSNMP
%{perl_vendorarch}/auto/Bundle
%{perl_vendorarch}/SNMP.pm
%{perl_vendorarch}/NetSNMP
%{_bindir}/tkmib
%if 0%{?suse_version} <= 1130
/var/adm/perl-modules/net-snmp
%endif

%files python
%defattr(-,root,root)
%doc README
%{python_sitearch}/*

%changelog
* Fri Sep 25 2015 meissner@suse.com
- revert the --disable-md5 as it breaks various applications bsc#944302
- net-snmp-reenable-md5-fips.patch: allow MD5 in FIPS mode for the api.
* Thu Aug 13 2015 abergmann@suse.com
- fix an incomplete initialization vulnerability within the
  snmp_pdu_parse() function of snmp_api.c. (bnc#940188, CVE-2015-5621)
  * net-snmp-5.7.3-fix-snmp_pdu_parse-incomplete.patch
- rename patches to new version number 5.7.3:
  delete:
  * net-snmp-5.7.2-fix-snmpd-crashing-when-an-agentx-disconnects.patch
  * net-snmp-5.7.2-net-snmp-config-headercheck.patch
  * net-snmp-5.7.2-perl-tk-warning.patch
  * net-snmp-5.7.2-pie.patch
  * net-snmp-5.7.2-socket-path.patch
  * net-snmp-5.7.2-testing-empty-arptable.patch
  * net-snmp-5.7.2-velocity-mib.patch
  add:
  * net-snmp-5.7.3-fix-snmpd-crashing-when-an-agentx-disconnects.patch
  * net-snmp-5.7.3-net-snmp-config-headercheck.patch
  * net-snmp-5.7.3-perl-tk-warning.patch
  * net-snmp-5.7.3-pie.patch
  * net-snmp-5.7.3-socket-path.patch
  * net-snmp-5.7.3-testing-empty-arptable.patch
  * net-snmp-5.7.3-velocity-mib.patch
- add support for hostname netgroups (FATE#316305)
  '@hostgroup' can be specified for multiple hosts
  patch based on: https://sourceforge.net/p/net-snmp/patches/1266/
  * net-snmp-5.7.3-netgroups.patch
- suppress network statistics output in snmpstatus (FATE#316289)
  '-Sn' don't print any info about the network
  '-Si' don't print the operational status of network interfaces
  * net-snmp-5.7.3-snmpstatus-suppress-output.patch
- also stop snmptrapd on removal
* Fri Aug  7 2015 meissner@suse.com
- --disable-md5 to allow operation in FIPS mode. (and not use the
  old algorithm, bsc#935876 bsc#940084)
* Tue Jul 14 2015 abergmann@suse.com
- update to upstream version 5.7.3.
  * added btrfs support to hrFSTable (bsc#909479)
- Add build requirement 'procps' to fix a net-snmp-config error.
  (bsc#935863)
- Enable DTLS and TLS support in net-snmp. (FATE#318789)
  (--with-security-modules=tsm --with-transports=TLSTCP,DTLSUDP)
- Removed upstream patches in 5.7.3:
  net-snmp-5.7.2-build-fix-for-strlcat.patch
  net-snmp-5.7.2-fix-mib-representation-of-timeout-values.patch
  net-snmp-5.7.2-fix-perl-trap-handler.patch
  net-snmp-5.7.2-fix-snmptrapd-remote-denial-of-service.patch
* Tue Sep  2 2014 abergmann@suse.com
- added net-snmp-5.4.x_fix-snmptrapd-remote-denial-of-service.patch:
  fix remote denial of service problem inside snmptrapd when started
  with the "-OQ" option (CVE-2014-3565)(bnc#894361)
- added net-snmp-5.4.x_fix-perl-trap-handler.patch: fix potential
  remote denial of service problem inside the snmptrapd Perl trap
  handler (CVE-2014-2285)(bnc#866942)
* Mon Jun 16 2014 lchiquitto@suse.de
- merge some old fixes from SLE 11:
  * init script should provide snmpd. (bnc#466805)
  * stop all snmp agents when stopping the daemon. (bnc#473328)
* Fri May 16 2014 lchiquitto@suse.com
- update to upstream version 5.7.2.1, fixing one security issue:
  * A denial of service attack vector was discovered on the Linux
    implementation of the ICMP-MIB. (CVE-2014-2284, bnc#866942)
* Wed May 14 2014 lchiquitto@suse.com
- net-snmp-5.7.2-fix-mib-representation-of-timeout-values.patch:
  fix mib representation of timeout values (bnc#833153)
* Thu May  8 2014 ro@suse.de
- use _rundir macro
* Tue Feb 18 2014 lchiquitto@suse.com
- remove old workaround for ppc/ppc64 migrations which is no longer
  needed (bnc#437293)
* Mon Jul 15 2013 mardnh@gmx.de
- add support for python bindings
* Wed Jul 10 2013 lars@linux-schulserver.de
- improve snmptrapd init script (avoid to overwrite the logfile
  on restart)
* Mon May 20 2013 lchiquitto@suse.com
- Disable parallelism during build. The dependencies between the
  Perl module and libnetsnmp are not defined correctly and might
  result in broken linkage (bnc#819497, bnc#818907)
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Dec 18 2012 lchiquitto@suse.com
- net-snmp-5.7.2-build-fix-for-strlcat.patch: fix exported strlcat()
  prototype that could conflict with other packages (bnc#793548)
* Wed Oct 10 2012 lchiquitto@suse.com
- update to version 5.7.2: several bug fixes in the agent, client
  utilities and libraries. The CHANGES file shipped with the
  package contains a comprehensive list of fixes and improvements
- rebase patches to apply cleanly:
  * net-snmp-5.7.2-perl-tk-warning.patch
  * net-snmp-5.7.2-socket-path.patch
  * net-snmp-5.7.2-testing-empty-arptable.patch
  * net-snmp-5.7.2-pie.patch
  * net-snmp-5.7.2-velocity-mib.patch
  * net-snmp-5.7.2-fix-snmpd-crashing-when-an-agentx-disconnects.patch
- remove patches that are now present in the upstream release:
  * net-snmp-5.7.0-recognize-reiserfs.patch
  * net-snmp-5.7.1-snmplib-zero-timeout.patch
  * net-snmp-5.7.1-old-api-double-free.patch
  * net-snmp-5.7.1-use-pclose-to-close-pipes.patch
  * net-snmp-5.7.1-fix-handling-of-large-filesystems.patch
  * net-snmp-5.7.1-snmplib-default-retries.patch
  * net-snmp-5.7.1-fsys-memory-leak.patch
  * net-snmp-5.7.1-adjust-copyright-in-agent-txt-file.patch
  * net-snmp-5.7.1-recognize-ocfs2.patch
  * net-snmp-5.7.1-properly-clean-up-old-requests-in-subagents.patch
  * net-snmp-5.7.1-reduce-code-duplication-in-agentx.patch
  * net-snmp-5.7.1-log-agentx-disconnections.patch
  * net-snmp-5.7.1-more-robust-handling-of-agentx-errors.patch
  * net-snmp-5.7.1-report-problems-with-setundo-processing.patch
  * net-snmp-5.7.1-fix-array-index-error.patch
* Fri Sep  7 2012 jengelh@inai.de
- Remove redundant sections from specfile
- Avoid shipping .la files
* Mon May 14 2012 lchiquitto@suse.com
- fix array index error that could lead to a crash (CVE-2012-2141)
  (bnc#759352)
* Thu Mar 29 2012 lchiquitto@suse.com
- fix agent crash when reloading a subagent (AgentX) during a query
  (bnc#670789)
* Thu Mar 29 2012 lchiquitto@suse.com
- add OCFS2 to the list of known file systems
* Thu Mar 22 2012 lchiquitto@suse.com
- update copyright notice of AGENT.txt allowing us to redistribute
  the file in our package (from Dave Shield) (bnc#750704)
* Wed Feb  8 2012 coolo@suse.com
- fix license to be in spdx.org format
* Tue Nov  1 2011 lchiquitto@suse.com
- logrotate: use "reload" instead of "try-restart" to avoid an
  unnecessary stop/start cycle in the agent (bnc#707636)
* Fri Oct 21 2011 lchiquitto@suse.com
- net-snmp-5.7.1-fsys-memory-leak.patch: fix a memory leak in
  agent/mibgroup/hardware/fsys (bnc#725766)
- net-snmp-5.7.1-snmplib-default-retries.patch: change default
  number of retries back from 0 to 5 (bnc#725766)
- net-snmp-5.7.1-fix-handling-of-large-filesystems.patch: fix
  bug in handling large (>8TB) filesystems (bnc#725766)
- net-snmp-5.7.1-use-pclose-to-close-pipes.patch: use pclose()
  instead of fclose() to close a pipe (bnc#725766)
- net-snmp-5.7.1-old-api-double-free.patch: agent: avoid double
  free when netsnmp_register_old_api() fails (bnc#725766)
- net-snmp-5.7.1-snmplib-zero-timeout.patch: snmplib: avoid
  waiting indefinitely if a session has timeout zero (bnc#725766)
* Thu Sep 29 2011 lchiquitto@suse.com
- update to version 5.7.1: minor release including some bug fixes
* Fri Sep 16 2011 jengelh@medozas.de
- enable net-snmp-devel on all baselib architectures
* Wed Sep 14 2011 lchiquitto@suse.com
- make sure all delegated requests are removed before closing an
  AgentX session (bnc#670789)
* Fri Sep  9 2011 lchiquitto@suse.com
- update to version 5.7.1.rc1 but keep package version as 5.7.1
  to avoid update problems when the final version is released
* Fri Sep  9 2011 lchiquitto@suse.com
- small fixes to snmpd and snmptrapd init scripts:
  - if $SNMPD_LOGLEVEL is not defined, use LOG_NOTICE instead of
    LOG_DEBUG
  - improve messages printed and service description
  - write snmptrapd logs to /var/log/net-snmpd.log
* Fri Sep  9 2011 lchiquitto@suse.com
- update README.SUSE to reflect some recent changes and drop a bit
  of outdated information
- update baselibs to reflect new library version
- spec file cleanup: rename some source files for consistency
* Thu Sep  1 2011 lchiquitto@suse.com
- add ReiserFS to the list of known file systems (bnc#715199)
* Tue Aug 30 2011 lchiquitto@suse.com
- install snmptrapd init script by default (bnc#712175)
* Tue Aug 30 2011 lchiquitto@suse.com
- fix logging option in snmptrapd init script (bnc#712174)
* Thu Jul 14 2011 lchiquitto@suse.com
- update upstream patches from branch V5-7-patches to 20110714
* Tue Jul  5 2011 lchiquitto@suse.com
- update to version 5.7:
  new features and lots of bug fixes
- remove patches that are no longer needed:
  net-snmp-5.6.0-enable-hrh-filesys.patch
  net-snmp-5.6.1-recognize-jfs-and-xfs.patch
  net-snmp-5.6.1-rpm490.patch
- refresh and rename patches to apply cleanly after update:
  net-snmp-5.7.0-pie.patch
  net-snmp-5.7.0-velocity-mib.patch
* Thu May 19 2011 mls@suse.de
- switch from rpmdb to rpmts to support rpm-4.9.0
* Thu May 12 2011 lchiquitto@suse.com
- update upstream patches from branch V5-6-patches to 20110512
* Wed Apr 13 2011 lchiquitto@suse.com
- add JFS and XFS to the list of known file systems (bnc#687327)
* Mon Mar 28 2011 lchiquitto@suse.com
- update upstream patches from branch V5-6-patches to 20110328
* Tue Jan  4 2011 lchiquitto@suse.com
- fix libsnmp version in baselibs.conf
* Tue Jan  4 2011 lchiquitto@suse.com
- update to version 5.6.1:
  new features and lots of bug fixes
- update upstream patches from branch V5-6-patches to 20110104
- remove patches that are no longer needed:
  net-snmp-5.6.0-ethtool-speed.patch
* Tue Nov 30 2010 lchiquitto@suse.com
- remove /var/adm/perl-modules/net-snmp from the Perl module
* Mon Nov 29 2010 lchiquitto@suse.com
- update upstream patches from branch V5-6-patches to 20101129
- spec file cleanup: upstream uses -fno-strict-aliasing by default
  now
- remove patches that are no longer needed:
  net-snmp-5.5.0-rpmdb-h-detect.patch
  net-snmp-5.6.0-vendorperl.patch
* Wed Nov  3 2010 lchiquitto@suse.com
- if-mib: add support for more speeds with ethtool (bnc#650558)
* Mon Nov  1 2010 lchiquitto@suse.com
- update upstream patches from branch V5-6-patches to 20101101,
  fixing a segmentation fault on shutdown (bnc#650282)
* Wed Oct 27 2010 lchiquitto@suse.com
- enable new implementation of hrStorage and hrFilesys to fix
  persistent indexes in FS and Storage tables (bnc#648364)
* Thu Oct 21 2010 lchiquitto@suse.com
- update upstream patches from branch V5-6-patches to 20101021
* Tue Oct 19 2010 lchiquitto@suse.com
- update to version 5.6:
  new features and lots of bug fixes
- refresh and rename patches to apply cleanly after update:
  net-snmp-5.6.0-pie.patch
  net-snmp-5.6.0-vendorperl.patch
  net-snmp-5.6.0-net-snmp-config-headercheck.patch
* Tue Aug  3 2010 lchiquitto@suse.com
- update upstream patches from branch V5-5-patches to 20100803
* Mon Jul 19 2010 lchiquitto@suse.com
- change default log level from DEBUG to NOTICE (bnc#623497)
* Fri Jul 16 2010 lchiquitto@suse.com
- spec file cleanup: remove old backward compatibility scripts
* Thu Jun  3 2010 lchiquitto@suse.com
- update upstream patches from branch V5-5-patches to 20100602:
  fixed potential buffer overflow in parsing OIDs in config files
* Mon May 31 2010 lchiquitto@suse.com
- update upstream patches from branch V5-5-patches to 20100531
- add net-snmp-5.5.0-rpmdb-h-detect.patch:
  workaround for autoconf failing to detect rpm/rpmdb.h
- remove patches that are no longer needed:
  net-snmp-5.5.0-use-lmsensors-v3.patch
* Fri Apr 30 2010 lchiquitto@suse.com
- create /var/run/agentx during startup to support systems that
  mount /var/run as tmpfs
* Wed Apr 28 2010 lchiquitto@suse.com
- update libsnmp package name to reflect the library version we
  are currently shipping
- remove patches that are obsolete:
  net-snmp-5.4.rc2-versinfo.diff
  net-snmp-5.4.2_snmpconf-selinux.patch
- refresh all patches to apply as "-p1"
- spec file cleanup: remove conditionals to build on unsupported
  versions of the distribution
* Wed Apr 28 2010 lchiquitto@suse.com
- update upstream patches from branch V5-5-patches to 20100428
* Mon Apr  5 2010 lchiquitto@suse.com
- add net-snmp-5.5.0_upstream-20100405.patch:
  merge all patches committed to upstream branch V5-5-patches
- remove patches that are now upstream:
  net-snmp-5.4.2_audit.patch
  net-snmp-5.5.0_autoconf.patch
  net-snmp-5.4.2_overflow.patch
  net-snmp-5.4.2.1-rpm4.7.patch
  net-snmp-5.5.0_gcc45.patch
* Fri Mar  5 2010 lchiquitto@suse.com
- Fix strncat properly (from Andreas Jaeger)
* Mon Mar  1 2010 aj@suse.de
- Fix code errors found by gcc 4.5
* Wed Feb  3 2010 jdelvare@suse.de
- build for libsensors4 instead of libsensors3
* Mon Feb  1 2010 jengelh@medozas.de
- remove sparcv9-specific baselib exceptions (not needed)
* Tue Jan 19 2010 lchiquitto@suse.com
- remove net-snmp-5.4.1.2-rmon-mib-revised_3.patch from sources
  (upstream since 5.5)
- refresh net-snmp-5.5.0_autoconf.patch
- spec file cleanup: update package description
* Tue Dec 22 2009 lchiquitto@suse.com
- update to version 5.5:
  new features and lots of bug fixes, including:
  - fix hrSWRunPath for processes other than init (bnc#486270)
- remove patches that are now upstream:
  Add-Default-Router-Table-support.patch
  Add-ICMP-Statistics-Tables-support.patch
  Add-IPv6-Scope-Zone-Index.patch
  Add-IPv6-support-on-Internet-Address-Translation-Tab.patch
  Fix-for-IPv6-Interface-Table.patch
  Fix-for-Internet-Address-Prefix-Table.patch
  Fix-for-Internet-Address-Table.patch
  Fix-for-tcpConnnectionTable-tcpListenerTable-udpEn.patch
  Improve-IP-Statistics-tables.patch
  net-snmp-5.3.0.1_trap-agent-addr_v2.patch
  net-snmp-5.4.1.2-etherlike-mib-revised_4.patch
  net-snmp-5.4.x_embedded_perl_error_message.patch
* Sat Dec 19 2009 jengelh@medozas.de
- add baselibs.conf as a source
- add baselib defs for SPARC
* Sun Aug 30 2009 aj@suse.de
- Fix build with rpm 4.7 (net-snmp-5.4.2.1-rpm4.7.patch)
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Thu Jan 22 2009 mrueckert@suse.de
- updated patches from Dell:
  Those patches incorporate the latest fixes for remarks from the
  upstream review
  old: net-snmp-5.4.1.2-rmon-mib-revised.patch
  new: net-snmp-5.4.1.2-rmon-mib-revised_3.patch
  old: net-snmp-5.4.1.2-etherlike-mib-revised_2.patch
  new: net-snmp-5.4.1.2-etherlike-mib-revised_4.patch
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during
  distupgrade (bnc#437293)
* Fri Dec  5 2008 mrueckert@suse.de
- fix the snmptrapd init script:
  1. make sure the config isnt loaded twice.
  2. do not truncate the net-snmp.log
  3. use SNMPD_LOGLEVEL aswell.
  4. write a pid
- update snmptrapd section in README.SuSE
- whitespace cleanup in both init scripts
* Fri Nov 21 2008 mrueckert@suse.de
- update patches from Dell:
  Upstream asked to reduce the logging in the mib module.
  old name net-snmp-5.4.1.2-etherlike-mib-revised_1.patch
  new name net-snmp-5.4.1.2-etherlike-mib-revised_2.patch
* Thu Nov 20 2008 mrueckert@suse.de
- Remove the recommends on perl-Tk again. We rely on the fixed
  warning in the perl_tk_warnings.patch. (bnc#443047)
* Tue Nov 11 2008 ro@suse.de
- SLE-11 uses PPC64 instead of PPC, adapt baselibs.conf
* Mon Nov 10 2008 mrueckert@suse.de
- added net-snmp-5.4.x_embedded_perl_error_message.patch:
  fix typo in error message (bnc#439857)
* Wed Nov  5 2008 mrueckert@suse.de
- update to 5.4.2.1: (bnc#440950) (CVE-2008-4309)
  fix crash in getbulk handling code
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Oct 24 2008 mrueckert@suse.de
- added net-snmp-5.4.2_velocity-mib.patch (FATE#303556)
* Fri Oct 24 2008 mrueckert@suse.de
- refreshed patches to apply cleanly:
  old: net-snmp-5.1.2-snmpconf-selinux.patch
  new: net-snmp-5.4.2_snmpconf-selinux.patch
  old: net-snmp-5.2.1-overflow.diff
  new: net-snmp-5.4.2_overflow.patch
  old: net-snmp-5.2.1.testing.empty_arptable.patch
  new: net-snmp-5.4.2_testing.empty_arptable.patch
  old: net-snmp-5.3.0.1-audit.diff
  new: nmp-5.4.2_audit.patch
  old: net-snmp-5.3_vendorperl.patch
  new: net-snmp-5.4.2_vendorperl.patch
  old: net-snmp-5.4.1-autoconf.diff
  new: net-snmp-5.4.2_autoconf.patch
  old: net-snmp-5.4.1_perl_tk_warning.patch
  new: net-snmp-5.4.2_perl_tk_warning.patch
  old: net-snmp-5.4_net-snmp-config_headercheck.patch
  new: net-snmp-5.4.2_net-snmp-config_headercheck.patch
* Fri Oct 24 2008 kkeil@suse.de
- more IPv6 support from IBM (mainline backports) (bnc#437208)
  Fix-for-tcpConnnectionTable-tcpListenerTable-udpEn.patch
  Fix-for-IPv6-Interface-Table.patch
  Fix-for-Internet-Address-Table.patch
  Add-ICMP-Statistics-Tables-support.patch
  Add-Default-Router-Table-support.patch
  Add-IPv6-support-on-Internet-Address-Translation-Tab.patch
  Fix-for-Internet-Address-Prefix-Table.patch
  Add-IPv6-Scope-Zone-Index.patch
  Improve-IP-Statistics-tables.patch
* Mon Oct 20 2008 mrueckert@suse.de
- remove lzma-alpha-devel. rpm-devel has to require it if it is
  really needed
* Tue Sep 16 2008 mrueckert@suse.de
- updated patches from Dell:
  net-snmp-5.4.1.2-etherlike-mib-revised_1.patch
  net-snmp-5.4.1.2-rmon-mib-revised.patch
  Those 2 patches obsolete the previous 3 patches.
* Sat Sep 13 2008 mrueckert@suse.de
- fix typo in the init script which breaks loading of agents
  (bnc#415127)
- also restart snmptrapd after logrotate (bnc#378069)
* Fri Sep 12 2008 mrueckert@suse.de
- add patches from Dell: (Fate#304310)
  net-snmp-5.4.1.2-etherlike-mib-revised.patch
  net-snmp-5.4.1.2-rmon-mib.patch
  net-snmp-5.4.2_fix_dell_patches.patch
* Sat Sep  6 2008 mrueckert@suse.de
- update to version 5.4.2
  - [PATCH 1921861]: Avoid endless loop after truncating 64bit int
  - Better handling of CONTAINER_INSERT failures with multiple
    indices
  - [PATCH 2023633]: add SCTP-MIB implementation (Linux only)
  - suppress annoying "registration != duplicate" warning for root
    oids
  - Update to libtool 1.5.26
- add net-snmp-5.4.1_perl_tk_warning.patch (bnc#392695)
  correctly recommend installing the perl-Tk package instead of
  referring to cpan.
- fix Required-Stop in the init scripts
- cleanup the spec file:
  - moved files from the mibs package to the packages where they
    really belong (snmpconf-data, mib2c)
  - move mib2c from the perl package to the devel package
* Mon Aug 25 2008 prusnak@suse.cz
- fixed wrong SELinux context (selinux.patch) [Fate#303662]
* Fri Aug 22 2008 mrueckert@suse.de
- fix init scripts
- use %%fillup_only as we dont launch the daemon per default
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Mar 24 2008 ro@suse.de
- added lzma-alpha-devel to buildreq
* Fri Nov  2 2007 jdelvare@suse.de
- libsensors is in a separate package now.
* Wed Aug  1 2007 mrueckert@suse.de
- update to 5.4.1
  many small fixes. the highlights:
  - link only needed libraries
  - memleaks fixed
  - python bindings (not yet packaged)
- rediffed net-snmp-5.4.rc1-autoconf.diff
  new name net-snmp-5.4.1-autoconf.diff
- no longer build against lm_sensors on s390
- split out new packages:
  libsnmp15, snmp-mibs
* Mon Nov 13 2006 mrueckert@suse.de
- update to 5.4.rc2:
  tons of bugfixes, and new features. just to name a few:
  - enabled embedded perl
  - new MIB table to manage net-snmp access control extensions
  - hal to abstract os specific aspects of the systems
  - tree matching support for snmptrapd
  - reworked transport creation in snmplib
  - using the incoming ip for outgoing packets if possible.
  - ipv6 aware tcp/udp mibs
- removed patches:
  (all of them are either upstream or obsolete)
  net-snmp-5.2.1-acinclude.diff
  net-snmp-5.2.1-acquotation.patch
  net-snmp-5.2.1-compat.patch
  net-snmp-5.2.1-localperl.diff
  net-snmp-5.2.1-perl.diff
  net-snmp-5.3.0.1-64bit.diff
  net-snmp-5.3.0.1_agentx_socket_path_doc.patch
  net-snmp-5.3.0.1_deprecated_sysctl_retrans_time.patch
  net-snmp-5.3.0.1_disman_mib_crash.patch
  net-snmp-5.3.0.1_ethtool.patch
  net-snmp-5.3.0.1_linux_types_header.patch
  net-snmp-5.3.0.1_missing_ifNumber.patch
  net-snmp-5.3.0.1_netsnmp_register_mib_crash.patch
  net-snmp-5.3.0.1_perl_ld_run_path.patch
  net-snmp-5.3.0.1_sighup_vacm.patch
  net-snmp-5.3.0.1-smux-trap.diff
  net-snmp-5.3.0.1.tar.bz2
  net-snmp-5.3.0.1_tcpwrapper_log_severity.patch
  net-snmp-5.3.0.1_testsuite_no_smux.patch
  net-snmp-5.3.0.1_tunnel_compilation.patch
  net-snmp-5.3_perl_agent.xs-pointersize.patch
  net-snmp-5.3_perl-printf.patch
  net-snmp-5.4_default_store_return_value.patch
  oid-names2_5.3.patch
- added net-snmp-5.4_net-snmp-config_headercheck.patch:
  warn if net-snmp-config is used but development files are missing.
- updated net-snmp-5.2.1-autoconf.diff to apply cleanly against 5.4
  new name: net-snmp-5.4.rc1-autoconf.diff
- updated net-snmp-5.2.1-versinfo.diff to apply cleanly against 5.4
  new name: net-snmp-5.4.rc2-versinfo.diff
- added net-snmp-5.4.rc2_perl_SNMP_size_t.patch:
  dont use int if you want size_t. fixes failures in the perl test
  suite.
* Thu Oct 19 2006 mrueckert@suse.de
- added net-snmp-5.4_default_store_return_value.patch:
  backport my patch from 5.4 so we can get rid of the build errors.
  the patch removes/disables dead code.
* Fri Aug  4 2006 mrueckert@suse.de
- added net-snmp-5.3.0.1_perl_ld_run_path.patch:
  the old perl replacement line broke linking of the SNMP libraries
  into the perl modules. the patch sets the LD_RUN_PATH for the
  build process to LIBDIR. (#180888)
* Thu May  4 2006 mrueckert@suse.de
- added net-snmp-5.3.0.1_sighup_vacm.patch:
  The snmp agent was broken on SIGHUP. It lost all its MIB
  informations. (upstream bug: #1473289)
- added net-snmp-5.3.0.1_deprecated_sysctl_retrans_time.patch:
  The snmpd used a deprecated sysctl to get the retransmit time
  from the kernel. We didnt use this module but the mib library
  triggered the sysctl. The patch uses retrans_time_ms when
  available and corrects the correction factor for the old sysctl.
  (bug: #170140, upstream: #1437287)
- reenabled the lmsensors support. was disabled for testing and
  never reenabled.
* Thu Apr 20 2006 mrueckert@suse.de
- net-snmp-5.3.0.1_missing_ifNumber.patch:
  The 5.3 agent on Linux systems did not implement the 'ifNumber'
  MIB object. (#159501)
* Wed Apr 19 2006 mrueckert@suse.de
- logrotate does not like if the postrotate script returns with
  a non zero returncode.
- add missing "-e" in echo line
* Mon Apr  3 2006 mrueckert@suse.de
- dont call "/etc/init.d/snmpd restart". this could start the
  daemon unconditionally (too large log file).
  switched to "/etc/init.d/snmpd try-restart"
* Mon Apr  3 2006 mrueckert@suse.de
- run logrotate on startup if the logfile is too large. (#131072)
* Tue Mar 28 2006 mrueckert@suse.de
- fix compilation with ethtool support. (#155709)
- added option to ignore accepted connections (#86634)
  net-snmp-5.3.0.1_tcpwrapper_log_severity.patch
  new sysconfig option: SNMPD_LOG_SUCCESSFUL_CONNECTIONS
- pass the correct path to configure to set the desired log file
- make smux listen to localhost by default. (#116742)
- remove confpath patch. (#147808,#159768)
* Mon Mar 27 2006 mrueckert@suse.de
- updated and reenabled the audit patch
* Fri Mar 17 2006 mrueckert@suse.de
- ported sysconfig options from sles9
  SNMPD_LOGLEVEL -> SPECIFY the log level for the snmpd
  SNMPD_USE_SMUX -> disable SMUX socket
* Thu Mar  9 2006 mrueckert@suse.de
- disable embedded perl for now.
* Wed Mar  8 2006 mrueckert@suse.de
- added net-snmp-5.3.0.1_agentx_socket_path_doc.patch:
  fixes: net-snmp snmpd.conf(5) manpage gives wrong default
  for AgentXSocket (#129437)
- ported fix for bug #129923 from sles9
- suppress the error message in the ucd-snmp upgrade script
* Wed Feb 22 2006 mrueckert@suse.de
- we move the configs into /etc/snmp [#77935]
- removed debugging packages from the build requires.
* Thu Feb 16 2006 mrueckert@suse.de
- added net-snmp-5.3.0.1-smux-trap.diff
  dont loose the value of string variables via smux traps [#150091]
* Fri Feb  3 2006 mrueckert@suse.de
- added net-snmp-5.3.0.1_disman_mib_crash.patch
  o fixes a crash in the disman mib loading
- net-snmp-5.3.0.1_netsnmp_register_mib_crash.patch
  o dont crash while registering mibs
- net-snmp-5.3_perl_agent.xs-pointersize.patch
  o dont use int if you mean intptr_t(IV)
- net-snmp-5.3_perl-printf.patch
  o unused format specifier in printf
- net-snmp-5.3_vendorperl.patch
  o do make install_vendor
* Wed Jan 25 2006 mrueckert@suse.de
- removed net-snmp-5.2.1-cmdline.diff
  better solution from upstream
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 22 2006 mrueckert@suse.de
- update to version 5.3.0.1
- removed patches that got applied upstream or superseeded by
  upstream fixes:
  net-snmp-5.2.1-uptime.diff
  net-snmp-5.2.1-typeclash.diff
  net-snmp-5.2.1-gcc.diff
  net-snmp-5.2.1-dlopen-conf.diff
  net-snmp-5.2.1-enomedium.diff
  net-snmp-5.2.1-mktemp.diff
  net-snmp-5.2.1-close-all-fds.diff
  net-snmp-5.2.1-more-cpus.diff
  net-snmp-5.2.1-nowraplibs.patch
  net-snmp-5.2.1.set-var-value.patch
- added 4 new patches:
  net-snmp-5.3_perl_agent.xs-pointersize.patch
  - fixes some casts of pointers to ints -> segfaults in the test
    suite
  net-snmp-5.3_perl-printf.patch
  - fixes a printf warning
  net-snmp-5.3_vendorperl.patch
  - call perl modules install with install_vendor
  net-snmp-5.1.1-pie.patch
  - build snmpd and snmptrapd with pie
* Tue Nov 15 2005 uli@suse.de
- no point in running the test suite in QEMU
* Wed Sep  7 2005 mrueckert@suse.de
- Added rpm-devel to the requires of the -devel package
* Fri Jun 17 2005 mrueckert@suse.de
- added disman/event-mib to the mib list (Bug #91039)
- replaced patch25 (asn1 handling fix) with patch from the upstream.
  (Bug #73804)
- build snmpd and snmptrap with with -fpie/-pie
* Fri Jun 10 2005 mrueckert@suse.de
- Fixed test suite for boxes with empty arp tables.
* Tue May 17 2005 hvogel@suse.de
- Include the right header for compat mode (Bug #64074)
- Fix length for type ASN_UNSIGNED (Bug #73804)
- Get rid of WRAPLIBS in net-snmp-config (Bug #75879)
- Fix ac quotation
* Tue Feb 22 2005 meissner@suse.de
- moved tkmib and mib2c* to perl subpackage, since
  they require it. #63992
* Wed Feb 16 2005 meissner@suse.de
- Multiple non Intel CPU detection added.
* Sun Feb  6 2005 meissner@suse.de
- Upgraded to 5.1.2 release. (lots of bugfixes as usual)
* Wed Feb  2 2005 meissner@suse.de
- overflow counter32 and gauge32 on 64bit systems correctly. #50384
* Fri Nov 26 2004 meissner@suse.de
- close all non standard filedescriptors on start.
* Thu Nov 25 2004 meissner@suse.de
- Upgraded to 5.2 final.
* Mon Oct 25 2004 meissner@suse.de
- Upgraded to 5.2.1rc2. Dropped merged patches, rediffed
  old ones.
* Tue Aug 17 2004 coolo@suse.de
- fixing pre-requires
* Thu Aug 12 2004 meissner@suse.de
- Upgrade to 5.1.2 final.
* Thu Jul 29 2004 meissner@suse.de
- Upgraded to upstream 5.1.2.rc2.
* Fri Jul 23 2004 meissner@suse.de
- Upgraded to 5.1.2.rc1.
- Dropped some old patches / parts of old patches.
- Fixed problem on little endian 64bit machines.
* Thu Jul 15 2004 meissner@suse.de
- removed double free on failure in netsnmp_register_old_api().
  (bug #42580)
- do not specify -c /etc/snmpd.conf (since it is already built in).
  (bug #41706)
- require openssl-devel in -devel package.
* Tue Jul  6 2004 meissner@suse.de
- replaced undefined C construct (x[n] = y[n++]) which caused the
  testsuite to fail on i386.
* Mon Jul  5 2004 uli@suse.de
- sleep .3 s before starting agents (bug #42588)
* Wed Jun 30 2004 meissner@suse.de
- Fixed 2 places of file descriptor leakage which lead to segfaults
  during readdir/fgets. #33958
* Fri Mar 19 2004 meissner@suse.de
- remove the #define PACKAGE_ from the included autoconf
  generated config.h file. #36355
* Thu Mar 18 2004 ro@suse.de
- use stop_on_removal and restart_on_update macros (#36306)
- package /var/log/net-snmp as %%ghost (#36435)
* Tue Mar 16 2004 ro@suse.de
- use mktemp in fixproc (#36103)
* Mon Mar 15 2004 ro@suse.de
- avoid segfault in version-info (limit to 300 bytes)
- open devices with NONBLOCK, don't wait for cdrom
- avoid segfault in proc-cmdline output
* Mon Feb 16 2004 ro@suse.de
- previous 64-bit fix went just one bit too far, fixed
* Wed Feb 11 2004 ro@suse.de
- added smux mib (for quagga)
* Mon Feb  9 2004 ro@suse.de
- fix dlopen detection in configure
* Wed Feb  4 2004 ro@suse.de
- added requires for perl-TermReadKey
* Tue Jan 20 2004 ro@suse.de
- try to fix at least some 64bit issues (eg. #33958)
* Thu Jan 15 2004 ro@suse.de
- update arguments in rc-script
* Fri Jan  9 2004 kukuk@suse.de
- Fix some 64bit critical compiler warnings
* Fri Dec 12 2003 hare@suse.de
- Fixed includes for build with evlog.
* Fri Nov 14 2003 ro@suse.de
- update to 5.1
* Fri Nov 14 2003 ro@suse.de
- build perl module as perl-SNMP
* Fri Nov 14 2003 ro@suse.de
- enable ucd-snmp compatibility
* Thu Oct 23 2003 ro@suse.de
- update to 5.1.pre2
* Thu Oct 23 2003 ro@suse.de
- revised audit patch
- branched devel subpackage
- added rpm support
* Wed Oct 22 2003 ro@suse.de
- created package and ported patches from ucd-snmp
